==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentGeneralPanel.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentGeneralPanel", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../../app/config/constants/fragmentConfigurationRoles', '../../../../app/config/constants/freemarkerFragmentEntryProcessor', '../../../../app/selectors/selectSegmentsExperienceId', '../../../../app/store/index', '../../../../app/thunks/updateFragmentConfiguration', '../../../../prop-types/index', './FieldSet'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.FragmentGeneralPanel = void 0;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _fragmentConfigurationRoles = require("../../../../app/config/constants/fragmentConfigurationRoles");

    var _freemarkerFragmentEntryProcessor = require("../../../../app/config/constants/freemarkerFragmentEntryProcessor");

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../../app/selectors/selectSegmentsExperienceId"));

    var _index = require("../../../../app/store/index");

    var _updateFragmentConfiguration = _interopRequireDefault(require("../../../../app/thunks/updateFragmentConfiguration"));

    var _index2 = require("../../../../prop-types/index");

    var _FieldSet = require("./FieldSet");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    var FragmentGeneralPanel = function FragmentGeneralPanel(_ref) {
      var _fragmentEntryLink$co;

      var item = _ref.item;
      var dispatch = (0, _index.useDispatch)();
      var fragmentEntryLink = (0, _index.useSelectorCallback)(function (state) {
        return state.fragmentEntryLinks[item.config.fragmentEntryLinkId];
      }, [item.config.fragmentEntryLinkId]);
      var segmentsExperienceId = (0, _index.useSelector)(_selectSegmentsExperienceId["default"]);
      var fieldSets = (_fragmentEntryLink$co = fragmentEntryLink.configuration) === null || _fragmentEntryLink$co === void 0 ? void 0 : _fragmentEntryLink$co.fieldSets.filter(function (fieldSet) {
        return fieldSet.configurationRole !== _fragmentConfigurationRoles.FRAGMENT_CONFIGURATION_ROLES.style;
      });
      var defaultConfigurationValues = fragmentEntryLink.defaultConfigurationValues;
      var onValueSelect = (0, _react.useCallback)(function (name, value) {
        var configurationValues = getConfigurationValues(defaultConfigurationValues, fragmentEntryLink);

        var nextConfigurationValues = _objectSpread({}, configurationValues, _defineProperty({}, name, value));

        dispatch((0, _updateFragmentConfiguration["default"])({
          configurationValues: nextConfigurationValues,
          fragmentEntryLink: fragmentEntryLink,
          segmentsExperienceId: segmentsExperienceId
        }));
      }, [defaultConfigurationValues, dispatch, fragmentEntryLink, segmentsExperienceId]);
      return _react["default"].createElement(_react["default"].Fragment, null, fieldSets.map(function (fieldSet, index) {
        return _react["default"].createElement(_FieldSet.FieldSet, {
          fields: fieldSet.fields,
          key: index,
          label: fieldSet.label,
          onValueSelect: onValueSelect,
          values: getConfigurationValues(defaultConfigurationValues, fragmentEntryLink)
        });
      }));
    };

    exports.FragmentGeneralPanel = FragmentGeneralPanel;

    function getConfigurationValues(defaultConfigurationValues, fragmentEntryLink) {
      return _objectSpread({}, defaultConfigurationValues, {}, fragmentEntryLink.editableValues[_freemarkerFragmentEntryProcessor.FREEMARKER_FRAGMENT_ENTRY_PROCESSOR]);
    }
    //# sourceMappingURL=FragmentGeneralPanel.js.map
  }
});
//# sourceMappingURL=FragmentGeneralPanel.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentGeneralPanel.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentGeneralPanel", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../../app/config/constants/fragmentConfigurationRoles', '../../../../app/config/constants/freemarkerFragmentEntryProcessor', '../../../../app/selectors/selectSegmentsExperienceId', '../../../../app/store/index', '../../../../app/thunks/updateFragmentConfiguration', '../../../../prop-types/index', './FieldSet'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.FragmentGeneralPanel = void 0;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _fragmentConfigurationRoles = require("../../../../app/config/constants/fragmentConfigurationRoles");

    var _freemarkerFragmentEntryProcessor = require("../../../../app/config/constants/freemarkerFragmentEntryProcessor");

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../../app/selectors/selectSegmentsExperienceId"));

    var _index = require("../../../../app/store/index");

    var _updateFragmentConfiguration = _interopRequireDefault(require("../../../../app/thunks/updateFragmentConfiguration"));

    var _index2 = require("../../../../prop-types/index");

    var _FieldSet = require("./FieldSet");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    var FragmentGeneralPanel = function FragmentGeneralPanel(_ref) {
      var _fragmentEntryLink$co;

      var item = _ref.item;
      var dispatch = (0, _index.useDispatch)();
      var fragmentEntryLink = (0, _index.useSelectorCallback)(function (state) {
        return state.fragmentEntryLinks[item.config.fragmentEntryLinkId];
      }, [item.config.fragmentEntryLinkId]);
      var segmentsExperienceId = (0, _index.useSelector)(_selectSegmentsExperienceId.default);
      var fieldSets = (_fragmentEntryLink$co = fragmentEntryLink.configuration) === null || _fragmentEntryLink$co === void 0 ? void 0 : _fragmentEntryLink$co.fieldSets.filter(function (fieldSet) {
        return fieldSet.configurationRole !== _fragmentConfigurationRoles.FRAGMENT_CONFIGURATION_ROLES.style;
      });
      var defaultConfigurationValues = fragmentEntryLink.defaultConfigurationValues;
      var onValueSelect = (0, _react.useCallback)(function (name, value) {
        var configurationValues = getConfigurationValues(defaultConfigurationValues, fragmentEntryLink);

        var nextConfigurationValues = _objectSpread(_objectSpread({}, configurationValues), {}, _defineProperty({}, name, value));

        dispatch((0, _updateFragmentConfiguration.default)({
          configurationValues: nextConfigurationValues,
          fragmentEntryLink: fragmentEntryLink,
          segmentsExperienceId: segmentsExperienceId
        }));
      }, [defaultConfigurationValues, dispatch, fragmentEntryLink, segmentsExperienceId]);
      return (/*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, fieldSets.map(function (fieldSet, index) {
          return (/*#__PURE__*/_react.default.createElement(_FieldSet.FieldSet, {
              fields: fieldSet.fields,
              key: index,
              label: fieldSet.label,
              onValueSelect: onValueSelect,
              values: getConfigurationValues(defaultConfigurationValues, fragmentEntryLink)
            })
          );
        }))
      );
    };

    exports.FragmentGeneralPanel = FragmentGeneralPanel;

    function getConfigurationValues(defaultConfigurationValues, fragmentEntryLink) {
      return _objectSpread(_objectSpread({}, defaultConfigurationValues), fragmentEntryLink.editableValues[_freemarkerFragmentEntryProcessor.FREEMARKER_FRAGMENT_ENTRY_PROCESSOR]);
    }
    //# sourceMappingURL=FragmentGeneralPanel.js.map
  }
});
//# sourceMappingURL=FragmentGeneralPanel.js.map
